import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.Collections;
import java.util.List;

/**
 * The class demonstrates the use of Java NIO.2 features ito perform a
 * simple find-and-replace task.
 */
public class FindAndReplace {
    public static void main(String[] args) {
        try {
            // read the contents of the file "artists.txt" into a list of strings
            // note: the file contains various Unicode characters
            List<String> lines = Files.
                    readAllLines(Paths.get("artists.txt"), StandardCharsets.UTF_8);
            // find all lines matching "Peter Gene Hernandez" and replace each
            // with "Bruno Mars"
            Collections.replaceAll(lines, "Peter Gene Hernandez", "Bruno Mars");

            // write the modified lines into a file "new_artists.txt",
            // preserving Unicode encoding
            Files.write(Paths.get("new_artists.txt"), lines, StandardCharsets.UTF_8);

            // make a copy of the file "artists.txt" called "old_artists.txt"
            Files.copy(Paths.get("artists.txt"), Paths.get("old_artists.txt"),
                    StandardCopyOption.REPLACE_EXISTING);

        } catch (IOException e) {
            // in case of any IOException e.g. missing file,
            // just print the exception
            e.printStackTrace();
        }

    }
}
